@@ -5,16 +5,21 @@ use warnings;
 
 use base 'TAP::Object';
 
-our $VERSION = '3.43_03';
+our $VERSION = '3.43_04';
+
+                             # No EBCDIC support on early perls
+*to_native = (ord "A" == 65 || $] < 5.008)
+             ? sub { return shift }
+             : sub { utf8::unicode_to_native(shift) };
 
 # TODO:
 #   Handle blessed object syntax
 
 # Printable characters for escapes
 my %UNESCAPES = (
-    z => "\x00", a => "\x07", t    => "\x09",
-    n => "\x0a", v => "\x0b", f    => "\x0c",
-    r => "\x0d", e => "\x1b", '\\' => '\\',
+    z => "\x00", a => "\a",  t    => "\t",
+    n => "\n",   v => "\cK", f    => "\f",
+    r => "\r",   e => "\e",  '\\' => '\\',
 );
 
 my $QQ_STRING    = qr{ " (?:\\. | [^"])* " }x;
@@ -118,7 +123,8 @@ sub _read_qq {
 
     $str =~ s/\\"/"/gx;
     $str =~ s/ \\ ( [tartan\\favez] | x([0-9a-fA-F]{2}) ) 
-                 / (length($1) > 1) ? pack("H2", $2) : $UNESCAPES{$1} /gex;
+                 / (length($1) > 1) ? pack("H2", to_native($2))
+                                    : $UNESCAPES{$1} /gex;
     return $str;
 }
 
@@ -278,7 +284,7 @@ TAP::Parser::YAMLish::Reader - Read YAMLish data from iterator
 
 =head1 VERSION
 
-Version 3.43_03
+Version 3.43_04
 
 =head1 SYNOPSIS
 
