@@ -5,13 +5,18 @@ use warnings;
 
 use base 'TAP::Object';
 
-our $VERSION = '3.43_03';
+our $VERSION = '3.43_04';
 
-my $ESCAPE_CHAR = qr{ [ \x00-\x1f \" ] }x;
+                             # No EBCDIC support on early perls
+*from_native = (ord "A" == 65 || $] < 5.008)
+             ? sub { return shift }
+             : sub { utf8::native_to_unicode(shift) };
+
+my $ESCAPE_CHAR = qr{ [ [:cntrl:] \" ] }x;
 my $ESCAPE_KEY  = qr{ (?: ^\W ) | $ESCAPE_CHAR }x;
 
 my @UNPRINTABLE;
-$UNPRINTABLE[$_] = sprintf("x%02x", $_) for 0 .. ord(" ") - 1;
+$UNPRINTABLE[$_] = sprintf("x%02x", from_native($_)) for 0 .. ord(" ") - 1;
 $UNPRINTABLE[ord "\0"] = 'z';
 $UNPRINTABLE[ord "\a"] = 'a';
 $UNPRINTABLE[ord "\t"] = 't';
@@ -80,7 +85,7 @@ sub _enc_scalar {
     if ( $val =~ /$rule/ ) {
         $val =~ s/\\/\\\\/g;
         $val =~ s/"/\\"/g;
-        $val =~ s/ ( [\x00-\x1f] ) / '\\' . $UNPRINTABLE[ ord($1) ] /gex;
+        $val =~ s/ ( [[:cntrl:]] ) / '\\' . $UNPRINTABLE[ ord($1) ] /gex;
         return qq{"$val"};
     }
 
@@ -150,7 +155,7 @@ TAP::Parser::YAMLish::Writer - Write YAMLish data
 
 =head1 VERSION
 
-Version 3.43_03
+Version 3.43_04
 
 =head1 SYNOPSIS
 
